{



  THaAnalyzer* analyzer = THaAnalyzer::GetInstance();
  if( analyzer ) {
	analyzer->Close();
  } else {
	analyzer = new THaAnalyzer;
  }


  /////////////////////////////////////
  ///    Beams
  ////////////////////////////////////

  cout<<"replay: Adding Idea Beam"<< endl;

  THaApparatus* B = new THaIdealBeam("B","Idea Beam, for Test Only");
  gHaApps->Add( B );

  cout<<"replay: Adding L-arm Helicity"<< endl;
  B->AddDetector( new THaADCHelicity("adchel.L","Beam helicity L-arm") );
  B->AddDetector( new THaADCHelicity("adchel2.L","Beam helicity-2 L-arm") );
  B->AddDetector( new THaG0Helicity("g0hel.L","Left arm G0 helicity") );

  cout<<"replay: Adding UnRastered and Rastered Beam ..."<<endl;
  gHaApps->Add(new THaUnRasteredBeam("urb","Unrastered beam"));
  gHaApps->Add(new THaRasteredBeam("rb","Rastered Beam"));


 //////////////////////////////////////////
  ///   Other Modules
  ///////////////////////////////////////////

  cout<<"replay: Adding Decoder Data ..."<<endl;
  gHaApps->Add(new THaDecData("DL","Misc. Decoder Data"));

  ////////////////////////////////////////////
  ///    LHRS
  ///////////////////////////////////////////

  cout<<"replay: Adding HRS-L ..."<<endl;
  //THaApparatus* HRSL = new THaHRS("L","Left HRS");
  THaHRS* HRSL = new THaHRS("L","Left HRS");
  HRSL->SetTrSorting(true);
  gHaApps->Add( HRSL );
  

  // add detectors that are not in the default config
  //HRSL->AddDetector( new THaCherenkov("cer", "Gas Cherenkov counter" ));
  // HRSL->AddDetector( new THaCherenkov("a1", "A1 Cherenkov counter" ));
  //HRSL->AddDetector( new THaShower("prl1", "Pre-shower pion rej." ));
  //HRSL->AddDetector( new THaShower("prl2", "Show pion rej." ));
  // cout<<"replay: adding RICH detector ..."<<endl;
   //HRSL->AddDetector( new THaRICH("rich","The RICH"));

  cout<<"replay: adding LHRS track(physics) modules ..."<<endl;

  gHaPhysics->Add( new THaGoldenTrack("L.gold","Golden track for LHRS", "L") );



  ////////////////////////////////////////////
  ///    Big Bite
  ///////////////////////////////////////////

  printf("\n Loading BigBite Library...");
  gSystem->Load("libBigBite.so");

  THaBigBite* pB=new THaBigBite("BB","BigBite");
  pB->AddDetector(new TreeSearch::MWDC("mwdc","MWDC",pB));
  pB->AddDetector(new THaTriggerPlane("tp","Trigger Plane",pB));
  //pB->MountOptics(new THaOpticsAnalytical("optics","Analytical Bigbite Optics model",pB,"B"));
  pB->MountOptics(new THaOpticsHRS("optics","HRS Bigbite Optics model",pB,"B"));
  gHaApps->Add(pB);

  gHaPhysics->Add( new THaGoldenTrack("BB.gold","Golden track for BigBite", "BB") );

  //THaPhysicsModule *Rpt_l = new THaReactionPoint( "ReactPt_L","Reaction vertex for Left","L","B");
  THaPhysicsModule *Rpt_l = new THaReactionPoint( "ReactPt_L","Reaction vertex for Left","L","rb");
  gHaPhysics->Add( Rpt_l );
 
  //   Correct for using an Extended target
  // This needs information about the Point of interaction (hence a THaVertexModule)
  THaPhysicsModule* TgC_l = new THaExtTarCor("ExTgtCor_L", "Corrected for extended target, HRS-L", "L","ReactPt_L");
  gHaPhysics->Add( TgC_l );

  cout<<"replay: Adding Target ..."<<endl;
  THaHe3Target* pT=new THaHe3Target("he3","Hall A Polarized he3 target");
  gHaApps->Add(pT);





  //////////////////////////////////////
  ///    Physics
  /////////////////////////////////////

  cout<<"replay: adding Physics modules ..."<<endl;
  gHaPhysics->Add(new THaPrimaryKine("PriKineL","kinematics of scattering of electron to HRS","L","urb",.939565));
  gHaPhysics->Add(new THaPrimaryKine("PriKineLHe3","kinematics of scattering of electron to HRS","L","urb",3.016*0.931494));


  gSystem->Load("libVertexTime.so"); // now we load out package
  THaPhysicsModule* VertexTime = new THaVertexTime("VertexTime","Physics module for vertex time calculation ","BB","tp" ,0.511);
  gHaPhysics->Add(VertexTime);



  // add scalers
  THaScalerGroup* LeftScalers = new THaScalerGroup("Left");
  gHaScalers->Add(LeftScalers);


/*

stream testfile;

        testfile.open(fname,ios_base::in);
        Bool_t isopen=testfile.is_open();
        testfile.close();

Bool_t IsFileExist(const Char_t * fname)
{
        fstream testfile;

        testfile.open(fname,ios_base::in);
        Bool_t isopen=testfile.is_open();
        testfile.close();

        return isopen;
}
*/

  analyzer->EnableScalers();
 
  THaEvent* event = new THaEvent;
  
  int nrun, nev;
  int found = 0;

  char filename0[300];  
  char filename1[300];
  char filename2[300];
    
  FILE *fd;
  const char path[300] = "./raw";
  
  cout << "Run number?\n";
  cin >> nrun;
  if( nrun<0 ) break;
    
  cout << "Number of events to analyze (-1 for all) ?\n";
  cin >> nev;
    
  sprintf(filename0,"%s/e05102_%d.dat.0",path,nrun);
  cout<<"Run No.0 : "<<filename0<<endl;

  sprintf(filename1,"%s/e05102_%d.dat.1",path,nrun);
  cout<<"Run No.1 : "<<filename1<<endl;

  sprintf(filename2,"%s/e05102_%d.dat.2",path,nrun);
  cout<<"Run No.2 : "<<filename2<<endl;

  
  analyzer->SetEvent( event );
  char outname[300];
  sprintf(outname,"./ROOTfiles/epd_rootfile_%d.root",nrun);
  //run.SetFirstEvent(40000);
  analyzer->SetOutFile( outname );
  //if(nev>-1 && nev>40000) run.SetLastEvent(nev);
//  if(nev>-1) run.SetLastEvent(nev);
  analyzer->SetOdefFile("replay_L.odef");
  // analyzer->SetCutFile("replay_L.cdef");
  // File to record cuts accounting information
  char sumname[300];
  sprintf(sumname,"analysis_log.log");
  analyzer->SetSummaryFile(sumname); // optional

  THaRun run0(filename0);
  THaRun run1(filename1);
  THaRun run2(filename2);

  if(nev>-1) {
    run0.SetLastEvent(nev);
    analyzer->Process(run0);     // start the actual analysis
  }
  else {
    analyzer->Process(run0);     // start the actual analysis
    analyzer->Process(run1);     // start the actual analysis
    analyzer->Process(run2);     // start the actual analysis
  }
  cout<<"YOU JUST ANALYZED RUN number "<<nrun<<"."<<endl;


  
}
